@@ -58,6 +58,9 @@ class Spyglass:
         if self.dataset_id:
             self.cmd("session", self.dataset_id)
 
+    def close(self):
+        self._ws.close()
+
     def _on_open(self):
         def _auth(*args):
             self._ws.send(
