@@ -3,12 +3,12 @@ from time import sleep
 from loreiosdk.spyglass_script import Spyglass
 
 
-url = 'ws://dev01:10003/storyteller'
-user = 'maurin'
-pwd = 'MA123$%'
+url = 'wss://ui.getlore.io/storyteller'
+user = 'USR'
+pwd = 'PWD'
 
 
-spyglass = Spyglass(url, user, pwd, dataset_id='tvfplay')
+spyglass = Spyglass(url, user, pwd, dataset_id='DS')
 
 print(spyglass.cmd('ping'))
 
